@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2006 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2010 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -550,4 +550,24 @@ public class OXContext extends OXSOAPRMIMapper {
         }
     }
 
+    /**
+     * Same as {@link OXContextInterface#getAdminId(Context, Credentials)}
+     * 
+     * @param ctx
+     * @param auth
+     * @return
+     * @throws RemoteException
+     * @throws InvalidCredentialsException
+     * @throws StorageException
+     */
+    public int getAdminId(Context ctx, Credentials auth) throws RemoteException, InvalidCredentialsException, StorageException {
+        reconnect();
+        try {
+            return ((OXContextInterface)rmistub).getAdminId(ctx, auth);
+        } catch( ConnectException e) {
+            reconnect(true);
+            return ((OXContextInterface)rmistub).getAdminId(ctx, auth);
+        }
+    }
+
 }
